pub struct BwrapCmd<'a> {
chroot_path: Cow<'a, Utf8Path>,
bind_mounts: Vec<(&'a str, &'a str)>,
env_vars: Vec<(&'a str, &'a str)>,
}Expand description
Builder for running commands inside a target directory using bwrap.
Fields
chroot_path: Cow<'a, Utf8Path>The target directory to use as root for the container
bind_mounts: Vec<(&'a str, &'a str)>Bind mounts in format (source, target)
env_vars: Vec<(&'a str, &'a str)>Environment variables to set
Implementations
Sourceimpl<'a> BwrapCmd<'a>
impl<'a> BwrapCmd<'a>
Sourcepub fn new_with_dir(path: &'a Dir) -> Self
pub fn new_with_dir(path: &'a Dir) -> Self
Create a new BwrapCmd builder with a root directory as a File Descriptor.
Sourcepub fn bind(
self,
source: &'a impl AsRef<Utf8Path>,
target: &'a impl AsRef<Utf8Path>,
) -> Self
pub fn bind( self, source: &'a impl AsRef<Utf8Path>, target: &'a impl AsRef<Utf8Path>, ) -> Self
Add a bind mount from source to target inside the container.
Sourcepub fn setenv(self, key: &'a str, value: &'a str) -> Self
pub fn setenv(self, key: &'a str, value: &'a str) -> Self
Set an environment variable for the command.
Sourcepub fn set_default_path(self) -> Self
pub fn set_default_path(self) -> Self
Set $PATH to a reasonable default for finding system binaries.
The bwrap environment may not have a complete $PATH, causing tools like bootupctl or sfdisk to not be found. This sets a default that covers the standard binary directories.
Sourcefn build_command<S: AsRef<OsStr>>(
&self,
args: impl IntoIterator<Item = S>,
) -> Command
fn build_command<S: AsRef<OsStr>>( &self, args: impl IntoIterator<Item = S>, ) -> Command
Build the bwrap Command with all bind mounts, env vars, and args.
Sourcepub fn run<S: AsRef<OsStr>>(
self,
args: impl IntoIterator<Item = S>,
) -> Result<()>
pub fn run<S: AsRef<OsStr>>( self, args: impl IntoIterator<Item = S>, ) -> Result<()>
Run the specified command inside the container.
Sourcepub fn run_get_string<S: AsRef<OsStr>>(
self,
args: impl IntoIterator<Item = S>,
) -> Result<String>
pub fn run_get_string<S: AsRef<OsStr>>( self, args: impl IntoIterator<Item = S>, ) -> Result<String>
Run the specified command inside the container and capture stdout as a string.